@@ -1,5 +1,5 @@
 /* dom.h
- * $Id: dom.h 580 2006-08-04 21:13:04Z pajas $
+ * $Id: dom.h 609 2006-10-17 13:19:29Z pajas $
  * Author: Christian Glahn (2001)
  * 
  * This header file provides some definitions for wrapper functions.
@@ -246,4 +246,10 @@ domNodeNormalize( xmlNodePtr node );
 int
 domNodeNormalizeList( xmlNodePtr nodelist );
 
+int
+domRemoveNsRefs(xmlNodePtr tree, xmlNsPtr ns);
+
+void
+domAttrSerializeContent(xmlBufferPtr buffer, xmlAttrPtr attr);
+
 #endif
